@@ -24,6 +24,8 @@ class NodeFunction(object):
             raise Exception(f'invalid component file: {self.location}')
 
         spec = importlib.util.spec_from_file_location(self.name, self.location)
+        if spec is None:
+            raise Exception(f'invalid component spec: {self.location}')
         module = importlib.util.module_from_spec(spec)
         spec.loader.exec_module(module)
         return module
